<?php
class Page_Preview_Overlay extends ET_Builder_Module
{
	protected $module_credits = [
		'module_uri' => 'https://makeweb.com.au',
		'author' => 'MakeWeb',
		'author_uri' => 'https://makeweb.com.au',
	];
	
	public function init()
	{
		parent::init();
		$this->name             = 'Page Preview Overlay';
		$this->version          = '1.1.0';
		$this->slug             = 'mw_page_preview_overlay';
		$this->fb_support       = 'partial';
		$this->main_css_element = '%%order_class%%';
	}

	public function get_settings_modal_toggles()
	{
		return [
			'general' => [
				'toggles' => [
					'overlay' => esc_html__('Overlay Settings', 'ratchet'),
				],
			],
		];
	}
	
	public function get_custom_css_fields_config()
	{
		$fields = [];
		return $fields;
	}
	
	public function get_advanced_fields_config()
	{
		$advanced_fields = [];
		$advanced_fields["text"] = false;
		$advanced_fields["text_shadow"] = false;		
		return $advanced_fields;
	}

	public function get_fields()
	{
		$fields = [];
		
		$fields["overlay_cutoff"] = [
			'label' => esc_html__('Overlay Cutoff', 'ratchet'),
			'type' => 'range',
			'option_category' => 'configuration',
			'default' => '600px',
			'default_unit' => 'px',
			'default_on_front' => '600px',
			'allowed_units' => ['%', 'em', 'rem', 'px', 'cm', 'mm', 'in', 'pt', 'pc', 'ex', 'vh', 'vw'],
			'range_settings' => [
				'min' => '0',
				'max' => '2000',
				'step' => '1',
			],
			'hover' => 'tabs',
			'validate_unit' => true,
			'toggle_slug' => 'overlay',
		];
		
		$fields['overlay_colour'] = [
			'label' => esc_html__('Overlay Colour', 'ratchet'),
			'type' => 'select',
			'option_category' => 'configuration',
			'default' => 'light',
			'options' => [
				'light' => esc_html__('Light', 'ratchet'),
				'dark' => esc_html__('Dark', 'ratchet'),
			],
			'mobile_options' => true,
			'toggle_slug' => 'overlay',
		];
		
		$fields['active_menu'] = [
			'label' => esc_html__('Set First Menu Item as Active', 'ratchet'),
			'type' => 'yes_no_button',
			'option_category' => 'configuration',
				'options'          => array(
					'on'  => et_builder_i18n( 'Yes' ),
					'off' => et_builder_i18n( 'No' ),
				),
				'description'      => esc_html__( 'Adds a class to the first menu item to set it as active, useful for banners that mimic the homepage.', 'et_builder' ),

			'toggle_slug' => 'overlay',
		];
		
		return $fields;
	}
	

	public function render($attrs, $content, $render_slug)
	{
		$overlay_cutoff = $this->props['overlay_cutoff'];
		$overlay_colour = $this->props['overlay_colour'];
		$active_menu = $this->props['active_menu'];

		$output = sprintf(
			'<div %1$s class="%2$s mw_page_preview_overlay">
			</div>',
			$this->module_id(),
			$this->module_classname( $render_slug )
		);
		
		$originalHeightValue = intval($overlay_cutoff);
		
		$gradient_height = ($originalHeightValue * .3);
		$gradient_height = $gradient_height . 'px';
		
		$gradient = "background: linear-gradient(180deg,rgba(252,252,252,0) 0%,rgba(252,252,252,0.1) 4%,rgba(252,252,252,0.12) 5%,rgba(252,252,252,.6) 30%,rgba(252,252,252,1) 80%,rgba(255,255,255,1) 100%);";
		
		if($overlay_colour == 'dark'){
			$gradient = "background: linear-gradient(180deg,rgba(2,2,2,0) 0%,rgba(2,2,2,0.1) 4%,rgba(2,2,2,0.12) 5%,rgba(2,2,2,.6) 30%,rgba(2,2,2,1) 80%,rgba(0,0,0,1) 100%);";
		}
		
		$overlay = "
			$gradient
			pointer-events: none;
			position: absolute;
			width: 100vw;
			left: 0;
			right: 0;
			bottom: 0;	
			content: '';
			height: $gradient_height;
			z-index: 99999;";
		
		
		$body = "
		overflow: hidden;
		max-height: $overlay_cutoff; position: relative;";
		
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => "#main-content",
				'declaration' => $body,
			)
		);
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => "#main-content::after",
				'declaration' => $overlay,
			)
		);
		
		$footer = "display: none;";
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => "footer",
				'declaration' => $footer,
			)
		);
		$script = '';
		if($active_menu != 'off'){
		$script = "<script> jQuery(document).ready(function($) {
					$('header nav li:first').addClass('current-menu-item');
				});</script>";
		}
		
		return $output.$script;
	}
}
new Page_Preview_Overlay;